OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Lagt til i favoritter",
    "Removed from favorites" : "Fjernet fra favoritter",
    "You added {file} to your favorites" : "Du la til {file} i dine favoritter",
    "You removed {file} from your favorites" : "Du fjernet {file} fra dine favoritter",
    "Favorites" : "Favoritter",
    "File changes" : "Filendringer",
    "Created by {user}" : "Opprettet av {user}",
    "Changed by {user}" : "Endret av {user}",
    "Deleted by {user}" : "Slettet av {user}",
    "Restored by {user}" : "Gjenopprettet av {user}",
    "Renamed by {user}" : "Navn endret av {user}",
    "Moved by {user}" : "Flyttet av {user}",
    "\"remote account\"" : "\"ekstern konto\"",
    "You created {file}" : "Du opprettet {file}",
    "You created an encrypted file in {file}" : "Du opprettet en kryptert fil i {file}",
    "{user} created {file}" : "{user} opprettet {file}",
    "{user} created an encrypted file in {file}" : "{user} opprettet en kryptert fil i {file}",
    "{file} was created in a public folder" : "{file} ble opprettet i en offentlig mappe",
    "You changed {file}" : "Du endret {file}",
    "You changed an encrypted file in {file}" : "Du endret en kryptert fil i {file}",
    "{user} changed {file}" : "{user} endret {file}",
    "{user} changed an encrypted file in {file}" : "{user} endret en kryptert fil i {file}",
    "You deleted {file}" : "Du slettet {file}",
    "You deleted an encrypted file in {file}" : "Du slette en kryptert fil i {file}",
    "{user} deleted {file}" : "{user} slettet {file}",
    "{user} deleted an encrypted file in {file}" : "{user} slettet en kryptert fil i {file}",
    "You restored {file}" : "Du gjenopprettet {file}",
    "{user} restored {file}" : "{user} gjenopprettet {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Du endret navn på {oldfile} (skjult) til {newfile} (skjult)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Du endret navn på {oldfile} (skjult) til {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Du endret navn på {oldfile} til {newfile} (skjult)",
    "You renamed {oldfile} to {newfile}" : "Du endret navn på {oldfile} til {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : " {user} endret navn på {oldfile} (skjult) til {newfile} (skjult)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : " {user} endret navn på {oldfile} (skjult) til {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} endret navn på {oldfile} til {newfile} (skjult)",
    "{user} renamed {oldfile} to {newfile}" : " {user} endret navn på {oldfile} til {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttet {oldfile} til {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttet {oldfile} til {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har blitt lagt til eller fjernet fra dine <strong>favoritter</strong>",
    "Files" : "Filer",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe ble <strong>endret</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "En favoritt-fil eller mappe har blitt <strong>endret</strong>",
    "Failed to authorize" : "Autorisering feilet",
    "Invalid folder path" : "Ugyldig mappebane",
    "Folder not found" : "Mappe ikke funnet",
    "The file cannot be found" : "Kunne ikke finne filen",
    "The destination path does not exist: %1$s" : "Fildestinasjonen finnes ikke: %1$s",
    "You do not have permission to create a file at the specified location" : "Du har ikke tillattelse til å opprette en fil på denne plasseringen",
    "The file could not be converted." : "Filen kunne ikke konverteres.",
    "Could not get relative path to converted file" : "Kunne ikke hente relativ sti til den konverterte filen",
    "Limit must be a positive integer." : "Grensen må være et positivt heltall.",
    "The replacement character may only be a single character." : "Erstattelsestegnet kan kun være et enkelt tegn.",
    "Filename sanitization already started." : "Filnavnrensingen har allerede begynt.",
    "No filename sanitization in progress." : "Ingen filnavnrensing pågår.",
    "Favorite files" : "Favorittfiler",
    "No favorites" : "Ingen favoritter",
    "More favorites" : "Flere favoritter",
    "Accept" : "Aksepter",
    "Reject" : "Avvis",
    "Incoming ownership transfer from {user}" : "Ny eierskapsoverføring fra {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ønsker du å godta {path}?\n\nObs: Overføringsprosessen kan ta opp til 1 time.",
    "Ownership transfer denied" : "Eierskapsoverføring nektet",
    "Your ownership transfer of {path} was denied by {user}." : "Eierskapsoverføring av din {path} ble nektet av {user}.",
    "Ownership transfer failed" : "Overføring av eierskap mislyktes",
    "Your ownership transfer of {path} to {user} failed." : "Eierskapsoverføring din av {path} til {user} mislyktes.",
    "The ownership transfer of {path} from {user} failed." : "Eierskapsoverføring av {path} fra {user} mislyktes.",
    "Ownership transfer done" : "Overføring av eierskap ferdig",
    "Your ownership transfer of {path} to {user} has completed." : "Eierskapsoverføringen din av {path} til {user} er ferdig.",
    "The ownership transfer of {path} from {user} has completed." : "Eierskapsoverføring av {path} fra {user} er ferdig.",
    "in %s" : "om %s",
    "Transferred from %1$s on %2$s" : "Overført fra %1$s på %2$s",
    "File Management" : "Filbehandling",
    "Home" : "Hjem",
    "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
    "Reload current directory" : "Last inn gjeldende katalog på nytt",
    "Go to the \"{dir}\" directory" : "Gå til \"{dir}\"-katalogen",
    "Current directory path" : "Gjeldende katalogsti",
    "Share" : "Del med andre",
    "Your have used your space quota and cannot upload files anymore" : "Du har brukt opp plasskvoten og kan ikke laste opp filer lenger",
    "You do not have permission to upload or create files here." : "Du har ikke tillatelse til å laste opp eller opprette filer her.",
    "Drag and drop files here to upload" : "Dra og slipp filer her for å laste opp",
    "Favorite" : "Gjør til favoritt",
    "Back" : "Tilbake",
    "Toggle selection for file \"{displayName}\"" : "Veksle valg for fil \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Veksle valg for mappe \"{displayName}\"",
    "File is loading" : "Filen lastes inn",
    "Folder is loading" : "Mappen lastes inn",
    "Filename" : "Filnavn",
    "Folder name" : "Mappenavn",
    "This node is unavailable" : "Denne noden er utilgjengelig",
    "Another entry with the same name already exists." : "En annen oppføring med samme navnet finnes allerede.",
    "Invalid filename." : "Ugyldig filnavn.",
    "Rename file" : "Gi fil nytt navn",
    "Folder" : "Mappe",
    "Unknown file type" : "Ukjent filtype",
    "{ext} image" : "{ext}-bilde",
    "{ext} video" : "{ext}-video",
    "{ext} audio" : "{ext}-lyd",
    "{ext} text" : "{ext}-text",
    "Pending" : "Venter",
    "Unknown date" : "Ukjent dato",
    "Active filters" : "Aktivt filter",
    "Remove filter" : "Fjern filter",
    "Today" : "I dag",
    "Last 7 days" : "Siste 7 dager",
    "Last 30 days" : "Siste 30 dager",
    "This year ({year})" : "I år ({year})",
    "Last year ({year})" : "I fjor ({year})",
    "Custom date range" : "Egendefinert datoperiode",
    "Search everywhere" : "Søk overalt",
    "Documents" : "Dokumenter",
    "Spreadsheets" : "Regneark",
    "Presentations" : "Presentasjoner",
    "PDFs" : "PDFer",
    "Folders" : "Mapper",
    "Audio" : "Lyd",
    "Images" : "Bilder",
    "Videos" : "Filmer",
    "Filters" : "Filtere",
    "Appearance" : "Utseende",
    "Show hidden files" : "Vis skjulte filer",
    "Show file type column" : "Vis kolonne for filtype",
    "Show file extensions" : "Vis filtyper",
    "Crop image previews" : "Beskjær forhåndsvisninger av bilder",
    "General" : "Generell",
    "Sort favorites first" : "Sorter favoritter først",
    "Sort folders before files" : "Sorter mapper før filer",
    "Default view" : "Standardvisning",
    "All files" : "Alle filer",
    "Personal files" : "Personlige filer",
    "Additional settings" : "Flere innstillinger",
    "Actions" : "Handlinger",
    "File actions" : "Filhandlinger",
    "Selection" : "Valg",
    "Select all files" : "Velg alle filer",
    "Deselect all" : "Fjern all markering",
    "Select or deselect" : "Velg eller fjern valg",
    "Select a range" : "Velg område",
    "Navigation" : "Navigasjon",
    "Go to parent folder" : "Gå til overordnet mappe",
    "Go to file above" : "Gå til filen ovenfor",
    "Go to file below" : "Gå til filen nedenfor",
    "Go left in grid" : "Gå til venstre i rutenettet",
    "Go right in grid" : "Gå til høyre i rutenettet",
    "View" : "Vis",
    "Toggle grid view" : "Veksle rutenett-visning",
    "Show those shortcuts" : "Vis hurtigtastene",
    "Warnings" : "Advarsler",
    "Warn before changing a file extension" : "Varsle før endring av filtype",
    "WebDAV URL" : "WebDAV URL",
    "How to access files using WebDAV" : "Hvordan få tilgang til filer med WebDAV",
    "Total rows summary" : "Sammendrag av totalrader",
    "Toggle selection for all files and folders" : "Veksle valg for alle filer og mapper",
    "Name" : "Navn",
    "File type" : "Filtype",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "{displayName}: failed on some elements" : "{displayName}: feilet på noen elementer",
    "{displayName}: done" : "{displayName}: ferdig",
    "{displayName}: failed" : "{displayName}: feilet",
    "(selected)" : "(valgt)",
    "List of files and folders." : "Liste over filer og mapper.",
    "You have used your space quota and cannot upload files anymore." : "Du har brukt opp lagringskvoten din og kan ikke laste opp flere filer.",
    "Column headers with buttons are sortable." : "Kolonneoverskrifter med knapper kan sorteres.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denne listen er ikke fullstendig gjengitt av ytelsesgrunner. Filene gjengis når du navigerer gjennom listen.",
    "File not found" : "Finner ikke filen",
    "_{count} selected_::_{count} selected_" : ["{count} valgt","{count} valgt"],
    "Search scope options" : "Alternativer for søkeomfang",
    "Search here" : "Søk her",
    "Owner" : "Eier",
    "{usedQuotaByte} used" : "{usedQuotaByte} brukt",
    "{used} of {quota} used" : "{used} av {quota} brukt",
    "{relative}% used" : "{relative}% brukt",
    "Could not refresh storage stats" : "Kunne ikke oppdatere lagringsstatistikk",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
    "Storage information" : "Informasjon om lagring",
    "Storage quota" : "Lagringskvote",
    "New folder" : "Ny mappe",
    "Create new folder" : "Opprett ny mappe",
    "This name is already in use." : "Navnet er allerede i bruk.",
    "Create" : "Opprett",
    "Files starting with a dot are hidden by default" : "Filer som starter med punktum er som standard skjult",
    "Failed to start filename sanitization." : "Kunne ikke starte filnavnrensing.",
    "Failed to refresh filename sanitization status." : "Kunne ikke oppdatere status for filnavnrensing.",
    "Filename sanitization in progress." : "Filnavnrensing pågår.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "For øyeblikket er {processedUsers} av {totalUsers} kontoer allerede behandlet.",
    "Refresh" : "Oppdater",
    "All files have been santized for Windows filename support." : "Alle filer har blitt renset for å støtte filnavn i Windows.",
    "Some files could not be sanitized, please check your logs." : "Noen filer kunne ikke renses, vennligst sjekk loggene dine.",
    "Sanitization errors" : "Rensefeil",
    "Not sanitized filenames" : "Ikke-rensede filnavn",
    "Windows filename support has been enabled." : "Støtte for Windows-filnavn er blitt aktivert.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Selv om dette blokkerer brukere fra å opprette nye filer med ustøttede filnavn, eksisterende filer er enda ikke omdøpt og kan derfor fortsatt føre til problemer med synkronisering på Windows. ",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Du kan sette i gang navnbytting av filer med ugyldige filnavn, denne vil bli gjort i bakgrunnen og kan ta noe tid.",
    "Please note that this may cause high workload on the sync clients." : "Vær oppmerksom på at dette kan medføre høy arbeidsmengde på synkroniseringsklientene.",
    "Limit" : "Grense",
    "This allows to configure how many users should be processed in one background job run." : "Dette bestemmer hvor mange brukere kan bli behandlet i én bakgrunnsjobb.",
    "Sanitize filenames" : "Rens filnavn",
    "(starting)" : "(starter)",
    "Fill template fields" : "Fyll ut malfelt",
    "Submit" : "Send inn",
    "Choose a file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
    "Transfer" : "Overfør",
    "Transfer {path} to {userid}" : "Overfør {path} til {userid}",
    "Invalid path selected" : "Ugyldig angitt sti",
    "Unknown error" : "Ukjent feil",
    "Ownership transfer request sent" : "Forespørsel om overføring av eierskap er sendt",
    "Cannot transfer ownership of a file or folder you do not own" : "Kan ikke overføre eierskap til en fil eller mappe du ikke eier",
    "Transfer ownership of a file or folder" : "Eierskapsoverføring av en fil eller mappe",
    "Choose file or folder to transfer" : "Velg en fil eller mappe som skal overføres",
    "Change" : "Endre",
    "New owner" : "Ny eier",
    "Keep {old}" : "Behold {old}",
    "Keep without extension" : "Behold uten filtype",
    "Use {new}" : "Bruk {new}",
    "Remove extension" : "Fjern filendelse",
    "Change file extension" : "Endre filendelse",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Å endre filendelsen fra «{old}» til «{new}» kan føre til at filen ikke kan leses.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Å fjerne filendelsen «{old}» kan føre til at filen ikke kan leses.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Å legge til filendelsen «{new}» kan føre til at filen ikke kan leses.",
    "Do not show this dialog again." : "Ikke vis denne dialogen igjen.",
    "Cancel" : "Avbryt",
    "Rename" : "Gi nytt navn",
    "Select file or folder to link to" : "Velg fil eller mappe å koble til",
    "Choose {file}" : "Choose {file}",
    "Files settings" : "Filinnstillinger",
    "Switch to list view" : "Bytt til listevisning",
    "Switch to grid view" : "Bytt til rutevisning",
    "The file could not be found" : "Kunne ikke finne filen",
    "Upload was cancelled by user" : "Opplasting ble avbrutt av bruker",
    "Not enough free space" : "Ikke nok ledig diskplass",
    "Operation is blocked by access control" : "Operasjonen er blokkert på grunn av tilgangskontroll",
    "Error during upload: {message}" : "Feil under opplasting: {message}",
    "Error during upload, status code {status}" : "Feil under opplasting, statuskode {status}",
    "Unknown error during upload" : "Ukjent feil under opplasting",
    "Loading current folder" : "Laster gjeldende mappe",
    "Retry" : "Prøv igjen",
    "No files in here" : "Ingen filer",
    "Upload some content or sync with your devices!" : "Last opp innhold eller synkroniser med enhetene dine!",
    "Go back" : "Gå tilbake",
    "Views" : "Visninger",
    "Your files" : "Dine filer",
    "Open in files" : "Åpne i filer",
    "File cannot be accessed" : "Filen er ikke tilgjengelig",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen ble ikke funnet, eller du har ikke tillatelse til å vise den. Be avsenderen om å dele den.",
    "No search results for “{query}”" : "Ingen søkeresultater for \"{query}\"",
    "Search for files" : "Søk etter filer",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillat å begrense filnavn for å sikre at filer kan synkroniseres med alle klienter. Som standard er alle filnavn  gyldige på POSIX (f.eks. Linux eller macOS) tillatt.",
    "Files compatibility" : "Kompatibilitet med filer",
    "Enforce Windows compatibility" : "Håndhev Windows-kompatibilitet",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dette vil blokkere filnavn som ikke er gyldige på Windows-systemer, for eksempel å bruke reserverte navn eller spesialtegn. Men dette vil ikke håndheve kompatibiliteten til store og små bokstaver.",
    "Blank" : "Tom",
    "Unable to create new file from template" : "Kan ikke opprette ny fil fra malen",
    "Pick a template for {name}" : "Velg en mal for {name}",
    "Create a new file with the selected template" : "Opprett en ny fil med den valgte malen",
    "Creating file" : "Oppretter fil",
    "Save as {displayName}" : "Lagre som {displayName}",
    "Failed to convert files: {message}" : "Kunne ikke konvertere filer: {message}",
    "All files failed to be converted" : "Kunne ikke konvertere noen av filene",
    "One file could not be converted: {message}" : "Én fil kunne ikke konverteres: {message}",
    "Failed to convert files" : "Kunne ikke konvertere filene",
    "File successfully converted" : "Filen ble konvertert",
    "Failed to convert file: {message}" : "Kunne ikke konvertere filen: {message}",
    "Failed to convert file" : "Kunne ikke konvertere filen",
    "Delete" : "Slett",
    "Leave this share" : "Forlat denne delingen",
    "Leave these shares" : "Forlat disse delingene",
    "Disconnect storage" : "Koble fra lager",
    "Disconnect storages" : "Koble fra lagringer",
    "Delete permanently" : "Slett for godt",
    "Delete and unshare" : "Slett og opphev deling",
    "Delete file" : "Slett fil",
    "Delete files" : "Slett filer",
    "Delete folder" : "Slett mappe",
    "Delete folders" : "Slett mapper",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du er i ferd med å slette permanent {count} element","Du er i ferd med å slette permanent {count} elementer"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du er i ferd med å slette {count} element","Du er i ferd med å slette {count} elementer"],
    "Confirm deletion" : "Bekreft sletting",
    "Download" : "Last ned",
    "The requested file is not available." : "Den forespurte filen er ikke tilgjengelig.",
    "The requested files are not available." : "De forespurte filene er ikke tilgjengelige.",
    "Add to favorites" : "Legg til i favoritter",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add or remove favorite" : "Legg til eller fjern som favoritt",
    "Move" : "Flytt",
    "Copy" : "Kopier",
    "Move or copy" : "Flytt eller kopier",
    "Destination is not a folder" : "Målplassering er ikke en mappe",
    "This file/folder is already in that directory" : "Denne filen/mappen er allerede i den katalogen",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe til seg selv eller til en undermappe av seg selv",
    "A file or folder with that name already exists in this folder" : "En fil eller mappe med det navnet finnes allerede i denne mappen",
    "The files are locked" : "Filene er låst",
    "The file does not exist anymore" : "Filen finnes ikke lenger",
    "Choose destination" : "Velg målplassering",
    "Copy to {target}" : "Copy to {target}",
    "Move to {target}" : "Move to {target}",
    "Move or copy operation failed" : "Flytte- eller kopieringsoperason feilet",
    "Open folder" : "Åpne mappe",
    "Open folder {displayName}" : "Åpne mappe {displayName}",
    "Open in Files" : "Åpne i Filer",
    "Open locally" : "Åpne lokalt",
    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
    "Open file locally" : "Åpne fil lokalt",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen skal nå åpnes på enheten din. Om ikke, vennligst sjekk at du har skrivebordsprogrammet installert.",
    "Retry and close" : "Prøv igjen og lukk",
    "Open online" : "Åpne på nett",
    "Details" : "Detaljer",
    "View in folder" : "Vis i mappe",
    "Type" : "Type",
    "Created new folder \"{name}\"" : "Opprettet ny mappe \"{name}\"",
    "Unable to initialize the templates directory" : "Kan ikke initialisere mal-mappen",
    "Create templates folder" : "Opprett malmappe",
    "Templates" : "Maler",
    "New template folder" : "Ny malermappe",
    "In folder" : "I mappen",
    "Search in all files" : "Søk i alle filer",
    "Search in folder: {folder}" : "Søk i mappen: {folder}",
    "One of the dropped files could not be processed" : "En av de slupne filene kunne ikke behandles",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Nettleseren din støtter ikke Filesystem API. Kataloger vil ikke bli lastet opp.",
    "No files to upload" : "Ingen filer å laste opp",
    "Unable to create the directory {directory}" : "Kan ikke opprette katalogen {directory}",
    "Some files could not be uploaded" : "Noen filer kunne ikke lastes opp",
    "Files uploaded successfully" : "Filer opplastet",
    "No files to process" : "Ingen filer å behandle",
    "Files copied successfully" : "Filer ble kopiert",
    "Files moved successfully" : "Filer ble flyttet",
    "Some files could not be copied" : "Noen filer kunne ikke kopieres",
    "Some files could not be moved" : "Noen filer kunne ikke flyttes",
    "Conflicts resolution skipped" : "Konfliktløsning hoppet over",
    "Upload cancelled" : "Opplasting avbrutt",
    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøpe \"{oldName}\", den finnes ikke lenger",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" er allerede brukt i mappen \"{dir}\". Velg et annet navn.",
    "Could not rename \"{oldName}\"" : "Kunne ikke omdøpe \"{oldName}\"",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This folder is unavailable, please try again later or contact the administration" : "Denne mappen er utilgjengelig, vennligst prøv igjen senere eller kontakt administrasjonen",
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Unexpected error: {error}" : "Uventet feil: {error}",
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n hidden_::_%n hidden_" : ["%n skjult","%n skjult"],
    "Filename must not be empty." : "Filnavn kan ikke være tomt.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" er ikke tillatt i et filnavn.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" er et reservert navn og ikke tillatt for filnavn.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" er ikke en tillatt filtype.",
    "Filenames must not end with \"{extension}\"." : "Filnavn må ikke slutte med \"{extension}\".",
    "List of favorite files and folders." : "Liste over favorittfiler og mapper.",
    "No favorites yet" : "Ingen favoritter enda",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
    "List of your files and folders." : "Liste over dine filer og mapper.",
    "Folder tree" : "Mappetre",
    "List of your files and folders that are not shared." : "Liste over dine filer og mapper som ikke er delt.",
    "No personal files found" : "Ingen personlige filer funnet",
    "Files that are not shared will show up here." : "Filer som ikke er delt vil vises her.",
    "Recent" : "Nylig",
    "List of recently modified files and folders." : "Liste over nylig endrede filer og mapper.",
    "No recently modified files" : "Ingen nylig endrede filer",
    "Files and folders you recently modified will show up here." : "Filer og mapper du nylig har endret, vises her.",
    "Search" : "Søk",
    "Search results within your files." : "Søkeresultater innenfor dine filer.",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne serveren.",
    "%1$s (renamed)" : "%1$s (har fått nytt navn)",
    "Upload (max. %s)" : "Opplasting (maks %s)",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Det er også mulig å migrere filer automatisk etter at denne innstillingen er aktivert, se dokumentasjonen for occ-kommandoen.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøpte \"{oldName}\" tl \"{newName}\"",
    "Clear filter" : "Tøm filter",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" feilet på noen elementer",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massehandling utført",
    "\"{displayName}\" action failed" : "\"{displayName}\"-handling feilet",
    "Submitting fields …" : "Sender inn felt ...",
    "Shared by link" : "Delt med lenke",
    "Shared" : "Delt",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling utført",
    "Filter file names …" : "Filtrer filnavn ...",
    "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
    "WebDAV URL copied to clipboard" : "WebDAV-URL kopiert til utklippstavlen",
    "Enable the grid view" : "Aktiver rutenettvisningen",
    "Enable folder tree" : "Aktiver mappetre",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopiert til utklippstavlen",
    "Use this address to access your Files via WebDAV" : "Bruk denne adressen for tilgang til filene dine via WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktivert 2FA, må du opprette og bruke et nytt app-passord ved å klikke her.",
    "Show a warning dialog when changing a file extension." : "Vis en varslingsdialog ved endring av filtype.",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Speed up your Files experience with these quick shortcuts." : "Jobb raskere med filer ved å bruke disse hurtigtastene.",
    "Open the actions menu for a file" : "Åpner handlingsmenyen for en fil",
    "Rename a file" : "Gi nytt navn til en fil",
    "Delete a file" : "Slett en fil",
    "Favorite or remove a file from favorites" : "Legg til og fjern en fil fra Favoritter",
    "Manage tags for a file" : "Behandle merkelapper for en fil",
    "Deselect all files" : "Velg ingen filer",
    "Select or deselect a file" : "Velg eller fjern valget av en fil",
    "Select a range of files" : "Velg et utvalg av filer",
    "Navigate to the parent folder" : "Gå til overordnet mappe",
    "Navigate to the file above" : "Gå til filen over",
    "Navigate to the file below" : "Gå til filen under",
    "Navigate to the file on the left (in grid mode)" : "Gå til filen til venstre (i rutenettvisning)",
    "Navigate to the file on the right (in grid mode)" : "Gå til filen til høyre (i rutenettvisning)",
    "Toggle the grid view" : "Slå på/av rutenettvisning",
    "Open the sidebar for a file" : "Åpne sidepanelet for en fil",
    "You" : "Du",
    "Shared multiple times with different people" : "Del flere ganger med forskjellige personer",
    "Unable to change the favorite state of the file" : "Kunne ikke endre filens favorittilstand",
    "Error while loading the file data" : "Feil ved lasting av fildata",
    "Tags" : "Merkelapper",
    "Save as …" : "Lagre som ...",
    "Converting files …" : "Konverter filer ...",
    "Converting file …" : "Konverterer filer ...",
    "Deletion cancelled" : "Sletting avbrutt",
    "Edit locally" : "Rediger lokalt",
    "Moving \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Flytter \"{source}\" til \"{destination}\" …",
    "(copy)" : "(kopier)",
    "(copy %n)" : "(kopier %n)",
    "Move cancelled" : "Flytt avbrutt",
    "Cancelled move or copy of \"{filename}\"." : "Kansellert flytte- eller kopieroperasjon av \"{filename}\"",
    "Cancelled move or copy operation" : "Kansellert flytte- eller kopieroperasjon",
    "Open details" : "Åpne detaljer",
    "Photos and images" : "Fotoer og bilder",
    "New folder creation cancelled" : "Oppretting av ny mappe avbrutt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "All folders" : "Alle mapper",
    "Open file sidebar" : "Åpne sidepanelet for fil",
    "Search everywhere …" : "Søk overalt ...",
    "Search here …" : "Søk her ...",
    "Preparing …" : "Forbereder ..."
},
"nplurals=2; plural=(n != 1);");
